%global major_version 5.3
# Normally, this is the same as version, but... not always.
# No tests yet for 5.3.5
%global test_version 5.3.4
# Place rpm-macros into proper location.
%global macrosdir %(d=%{_rpmconfigdir}/macros.d; [ -d $d ] || d=%{_sysconfdir}/rpm; echo $d)


Name:           compat-lua5.3
Version:        %{major_version}.5
Release:        7.0.riscv64%{?dist}
Summary:        Powerful light-weight programming language
License:        MIT
URL:            http://www.lua.org/
Source0:        http://www.lua.org/ftp/lua-%{version}.tar.gz
# copied from doc/readme.html on 2014-07-18
Source1:        mit.txt
# multilib
Source4:        luaconf.h
Patch0:         lua-5.3.0-autotoolize.patch
Patch1:         lua-5.3.0-idsize.patch
Patch3:         lua-5.2.2-configure-linux.patch
Patch4:         lua-5.3.0-configure-compat-module.patch
Patch9:         CVE-2019-6706-use-after-free-lua_upvaluejoin.patch

BuildRequires:  automake autoconf libtool readline-devel ncurses-devel
Provides:       lua(abi) = %{major_version}

%description
Lua is a powerful light-weight programming language designed for
extending applications. Lua is also frequently used as a
general-purpose, stand-alone language. Lua is free software.
Lua combines simple procedural syntax with powerful data description
constructs based on associative arrays and extensible semantics. Lua
is dynamically typed, interpreted from bytecodes, and has automatic
memory management with garbage collection, making it ideal for
configuration, scripting, and rapid prototyping.

%prep
%setup -q -n lua-%{version}
cp %{SOURCE1} .
pwd
mv src/luaconf.h src/luaconf.h.template.in
%patch0 -p1 -E -z .autoxxx
%patch1 -p1 -z .idsize
%patch3 -p1 -z .configure-linux
%patch4 -p1 -z .configure-compat-all
%patch9 -p1 -b .CVE-2019-6706
# Put proper version in configure.ac, patch0 hardcodes 5.3.0
sed -i 's|5.3.0|%{version}|g' configure.ac
autoreconf -ifv

%build
%configure --with-readline --with-compat-module
sed -i 's|^hardcode_libdir_flag_spec=.*|hardcode_libdir_flag_spec=""|g' libtool
sed -i 's|^runpath_var=LD_RUN_PATH|runpath_var=DIE_RPATH_DIE|g' libtool
# Autotools give me a headache sometimes.
sed -i 's|@pkgdatadir@|%{_datadir}|g' src/luaconf.h.template

# hack so that only /usr/bin/lua gets linked with readline as it is the
# only one which needs this and otherwise we get License troubles
make %{?_smp_mflags} LIBS="-lm -ldl"
# only /usr/bin/lua links with readline now #luac_LDADD="liblua.la -lm -ldl"

%install
make install DESTDIR=$RPM_BUILD_ROOT
rm $RPM_BUILD_ROOT%{_libdir}/*.{a,la}

rm -rf $RPM_BUILD_ROOT%{_includedir}/l*h*
rm -rf $RPM_BUILD_ROOT%{_bindir}/*
rm $RPM_BUILD_ROOT%{_libdir}/liblua.so
rm $RPM_BUILD_ROOT%{_libdir}/pkgconfig/lua.pc
rm $RPM_BUILD_ROOT%{_mandir}/man1/lua.1
rm $RPM_BUILD_ROOT%{_mandir}/man1/luac.1

find $RPM_BUILD_ROOT

%files
%{!?_licensedir:%global license %%doc}
%license mit.txt
%{_libdir}/liblua-%{major_version}.so

%changelog
* Sat Dec 09 2023 David Abdurachmanov <davidlt@rivosinc.com> - 5.3.5-7.0.riscv64
- Compat package for pandoc
